@@ -13,7 +13,7 @@ use tauri_utils::platform::Target;
 pub fn items(frontend_dir: Option<&PathBuf>, tauri_dir: Option<&Path>) -> Vec<SectionItem> {
   let mut items = Vec::new();
   if tauri_dir.is_some() {
-    if let Ok(config) = crate::helpers::config::get(Target::current(), None) {
+    if let Ok(config) = crate::helpers::config::get(Target::current(), &[]) {
       let config_guard = config.lock().unwrap();
       let config = config_guard.as_ref().unwrap();
 
