@@ -3,12 +3,11 @@
 // SPDX-License-Identifier: MIT
 
 use crate::{
+  error::Context,
   helpers::app_paths::{frontend_dir, tauri_dir},
   Result,
 };
 
-use anyhow::Context;
-
 mod config;
 mod frontend;
 mod manifest;
