@@ -9,7 +9,6 @@ use crate::{
   ConfigValue, Result,
 };
 use cargo_mobile2::{
-  android::env::Env as AndroidEnv,
   config::app::App,
   reserved_names::KOTLIN_ONLY_KEYWORDS,
   util::{
@@ -39,8 +38,7 @@ pub fn command(
     reinstall_deps,
     skip_targets_install,
     config,
-  )
-  .map_err(|e| anyhow::anyhow!("{:#}", e))?;
+  )?;
   Ok(())
 }
 
@@ -81,6 +79,8 @@ pub fn exec(
         if r.is_match(&bin_stem.to_string_lossy()) {
           if var_os("PNPM_PACKAGE_NAME").is_some() {
             return ("pnpm".into(), build_args);
+          } else if is_pnpm_dlx() {
+            return ("pnpm".into(), vec!["dlx", "@tauri-apps/cli"]);
           } else if let Some(npm_execpath) = var_os("npm_execpath") {
             let manager_stem = PathBuf::from(&npm_execpath)
               .file_stem()
@@ -117,39 +117,35 @@ pub fn exec(
   build_args.push(target.command_name());
   build_args.push(target.ide_build_script_name());
 
-  map.insert("tauri-binary", binary.to_string_lossy());
+  let mut binary = binary.to_string_lossy().to_string();
+  if binary.ends_with(".exe") || binary.ends_with(".cmd") || binary.ends_with(".bat") {
+    // remove Windows-only extension
+    binary.pop();
+    binary.pop();
+    binary.pop();
+    binary.pop();
+  }
+
+  map.insert("tauri-binary", binary);
   map.insert("tauri-binary-args", &build_args);
   map.insert("tauri-binary-args-str", build_args.join(" "));
 
   let app = match target {
     // Generate Android Studio project
-    Target::Android => match AndroidEnv::new() {
-      Ok(_env) => {
-        let (config, metadata) =
-          super::android::get_config(&app, tauri_config_, None, &Default::default());
-        map.insert("android", &config);
-        super::android::project::gen(
-          &config,
-          &metadata,
-          (handlebars, map),
-          wrapper,
-          skip_targets_install,
-        )?;
-        app
-      }
-      Err(err) => {
-        if err.sdk_or_ndk_issue() {
-          Report::action_request(
-            " to initialize Android environment; Android support won't be usable until you fix the issue below and re-run `tauri android init`!",
-            err,
-          )
-          .print(wrapper);
-          app
-        } else {
-          return Err(err.into());
-        }
-      }
-    },
+    Target::Android => {
+      let _env = super::android::env(non_interactive)?;
+      let (config, metadata) =
+        super::android::get_config(&app, tauri_config_, None, &Default::default());
+      map.insert("android", &config);
+      super::android::project::gen(
+        &config,
+        &metadata,
+        (handlebars, map),
+        wrapper,
+        skip_targets_install,
+      )?;
+      app
+    }
     #[cfg(target_os = "macos")]
     // Generate Xcode project
     Target::Ios => {
@@ -325,7 +321,7 @@ fn escape_kotlin_keyword(
   out.write(&escaped_result).map_err(Into::into)
 }
 
-fn app_root(ctx: &Context) -> Result<&str, RenderError> {
+fn app_root(ctx: &Context) -> std::result::Result<&str, RenderError> {
   let app_root = ctx
     .data()
     .get("app")
@@ -383,3 +379,17 @@ fn unprefix_path(
     )
     .map_err(Into::into)
 }
+
+fn is_pnpm_dlx() -> bool {
+  var_os("NODE_PATH")
+    .map(PathBuf::from)
+    .is_some_and(|node_path| {
+      let mut iter = node_path.components().peekable();
+      while let Some(c) = iter.next() {
+        if c.as_os_str() == "pnpm" && iter.peek().is_some_and(|c| c.as_os_str() == "dlx") {
+          return true;
+        }
+      }
+      false
+    })
+}
