@@ -163,6 +163,9 @@ pub enum Error {
   /// Illegal event name.
   #[error("only alphanumeric, '-', '/', ':', '_' permitted for event names: {0:?}")]
   IllegalEventName(String),
+  /// tokio oneshot channel failed to receive message
+  #[error(transparent)]
+  TokioOneshotRecv(#[from] tokio::sync::oneshot::error::RecvError),
 }
 
 impl From<getrandom::Error> for Error {
