@@ -14,7 +14,7 @@ use crate::{
   event::EventTarget,
   ipc::ScopeObject,
   runtime::dpi::{PhysicalPosition, PhysicalSize},
-  webview::NewWindowResponse,
+  webview::{NewWindowResponse, ScrollBarStyle},
   window::Monitor,
   Emitter, EventName, Listener, ResourceTable, Window,
 };
@@ -1211,6 +1211,25 @@ impl<R: Runtime, M: Manager<R>> WebviewWindowBuilder<'_, R, M> {
     self
   }
 
+  /// Specifies the native scrollbar style to use with the webview.
+  /// CSS styles that modifier the scrollbar are applied on top of the native appearance configured here.
+  ///
+  /// Defaults to [`ScrollBarStyle::Default`], which is the browser default.
+  ///
+  /// ## Platform-specific
+  ///
+  /// - **Windows**:
+  ///   - [`ScrollBarStyle::FluentOverlay`] requires WebView2 Runtime version 125.0.2535.41 or higher,
+  ///     and does nothing on older versions.
+  ///   - This option must be given the same value for all webviews that target the same data directory. Use
+  ///     [`WebviewWindowBuilder::data_directory`] to change data directories if needed.
+  /// - **Linux / Android / iOS / macOS**: Unsupported. Only supports `Default` and performs no operation.
+  #[must_use]
+  pub fn scroll_bar_style(mut self, style: ScrollBarStyle) -> Self {
+    self.webview_builder = self.webview_builder.scroll_bar_style(style);
+    self
+  }
+
   /// Allows overriding the the keyboard accessory view on iOS.
   /// Returning `None` effectively removes the view.
   ///
@@ -2023,9 +2042,9 @@ impl<R: Runtime> WebviewWindow<R> {
   /// Sets this window's minimum inner width.
   pub fn set_size_constraints(
     &self,
-    constriants: tauri_runtime::window::WindowSizeConstraints,
+    constraints: tauri_runtime::window::WindowSizeConstraints,
   ) -> crate::Result<()> {
-    self.window.set_size_constraints(constriants)
+    self.window.set_size_constraints(constraints)
   }
 
   /// Sets this window's position.
