@@ -186,16 +186,16 @@ async function addPluginListener<T>(
 ): Promise<PluginListener> {
   const handler = new Channel<T>(cb)
   try {
-    return invoke(`plugin:${plugin}|register_listener`, {
+    await invoke(`plugin:${plugin}|register_listener`, {
       event,
       handler
-    }).then(() => new PluginListener(plugin, event, handler.id))
+    })
+    return new PluginListener(plugin, event, handler.id)
   } catch {
     // TODO(v3): remove this fallback
     // note: we must try with camelCase here for backwards compatibility
-    return invoke(`plugin:${plugin}|registerListener`, { event, handler }).then(
-      () => new PluginListener(plugin, event, handler.id)
-    )
+    await invoke(`plugin:${plugin}|registerListener`, { event, handler })
+    return new PluginListener(plugin, event, handler.id)
   }
 }
 
